@@ -20,10 +20,9 @@ parse_request_url <- function(request_url, data_builder, after = NA, data_list =
 }
 
 
-# Parse a thread URL
 parse_thread_url <- function(request_url){
   json <- url_to_json(request_url %+% ".json?limit=500")
-  comments_exist <- get_thread_json(json)$num_comments > 0
+  comments_exist <- length(get_comment_json(json)) > 0
   list(
     thread = json |>
       get_thread_json() |>
@@ -34,7 +33,6 @@ parse_thread_url <- function(request_url){
   )
 }
 
-
 # Apply a builder function to data if it contains elements
 maybe_build <- function(data, builder) {
   if(length(data) > 0) builder(data) else NA
